@@ -8,6 +8,18 @@
         modify it under the terms of the GNU General Public License
         as published by the Free Software Foundation; either version
         2 of the License, or (at your option) any later version.
+	
+	This code is derived from:
+
+	genext2fs.c
+
+	ext2 filesystem generator for embedded systems
+	Copyright (C) 2000 Xavier Bestel <xavier.bestel@free.fr>
+
+	This program is free software; you can redistribute it and/or
+	modify it under the terms of the GNU General Public License
+	as published by the Free Software Foundation; version
+	2 of the License.
 **/
 
 #ifndef INCLUDE_UTIL_H
