@@ -8,6 +8,18 @@
 	modify it under the terms of the GNU General Public License
 	as published by the Free Software Foundation; either version
 	2 of the License, or (at your option) any later version.
+	
+	This code is derived from:
+
+	genext2fs.c
+
+	ext2 filesystem generator for embedded systems
+	Copyright (C) 2000 Xavier Bestel <xavier.bestel@free.fr>
+
+	This program is free software; you can redistribute it and/or
+	modify it under the terms of the GNU General Public License
+	as published by the Free Software Foundation; version
+	2 of the License.
 **/
 
 #ifdef HAVE_CONFIG_H
@@ -1204,7 +1216,9 @@ void showhelp(void)
 	/* mkimage.ext2fs */
 	fprintf(stderr, "Usage: %s [options]\n"
 	/* --------1---------2---------3---------4---------5---------6---------7---------8 */
-	"mkimge2fs Version " VERSION "\n"
+	"mkimge2fs " VERSION " (c) 2002-2005 N.Masuichi <nor at users.sourceforge.jp>\n"
+	"  derived from: genext2fs (C) 2000 Xavier Bestel <xavier.bestel at free.fr>\n"
+	"\n"
 	"Base image:\n"
 	"  -s image	Use this image as a starting point\n"
 	"               (default: Create NEW filesystem image.)\n"
