@@ -2,12 +2,24 @@
 /**
 	mkimgfatfs - create a FAT image like as mkisofs
 
-	Copyright (c) 2003 Masuichi Noritoshi <nor@users.sourceforge.jp>
+	Copyright (c) 2003-2005 Masuichi Noritoshi <nor@users.sourceforge.jp>
 
 	This program is free software; you can redistribute it and/or
 	modify it under the terms of the GNU General Public License
 	as published by the Free Software Foundation; either version
 	2 of the License, or (at your option) any later version.
+
+	This code is derived from:
+
+	genext2fs.c
+
+	ext2 filesystem generator for embedded systems
+	Copyright (C) 2000 Xavier Bestel <xavier.bestel@free.fr>
+
+	This program is free software; you can redistribute it and/or
+	modify it under the terms of the GNU General Public License
+	as published by the Free Software Foundation; version
+	2 of the License.
 **/
 
 #ifdef HAVE_CONFIG_H
@@ -178,6 +190,48 @@ TFatfs_AllocateCluster(TFatfs* fs)
 }
 
 
+/** **************************************************************************
+************************************************************************** **/
+/*
+	0    ... string terminator
+	1    ... illegal charactor
+	o.w. ... legal charactor (and it means it's code)
+
+	[RESTRICTION]
+	We assume our charactor code is ASCII.
+*/
+
+#define DOSTRM		0u
+#define DOSILG		1u
+static uint8 char_check_table[128] = {
+/*	+0	+1	+2	+3	+4	+5	+6	+7	*/
+	DOSTRM,	DOSILG,	DOSILG,	DOSILG,	DOSILG,	DOSILG,	DOSILG,	DOSILG,	
+	DOSILG,	DOSILG,	DOSILG,	DOSILG,	DOSILG,	DOSILG,	DOSILG,	DOSILG,	/*0x*/
+	DOSILG,	DOSILG,	DOSILG,	DOSILG,	DOSILG,	DOSILG,	DOSILG,	DOSILG,	
+	DOSILG,	DOSILG,	DOSILG,	DOSILG,	DOSILG,	DOSILG,	DOSILG,	DOSILG,	/*1x*/
+	DOSILG,	'!',	DOSILG,	'#',	'$',	'%',	'&',	'\'',	
+	'(',	')',	DOSILG,	DOSILG,	DOSILG,	'-',	'.',	DOSILG,	/*2x*/
+	'0',	'1',	'2',	'3',	'4',	'5',	'6',	'7',	
+	'8',	'9',	DOSILG,	DOSILG,	DOSILG,	DOSILG,	DOSILG,	DOSILG,	/*3x*/
+	'@',	'A',	'B',	'C',	'D',	'E',	'F',	'G',	
+	'H',	'I',	'J',	'K',	'L',	'M',	'N',	'O',	/*4x*/
+	'P',	'Q',	'R',	'S',	'T',	'U',	'V',	'W',	
+	'X',	'Y',	'Z',	DOSILG,	DOSILG,	DOSILG,	'^',	'_',	/*5x*/
+	DOSILG,	'A',	'B',	'C',	'D',	'E',	'F',	'G',	
+	'H',	'I',	'J',	'K',	'L',	'M',	'N',	'O',	/*6x*/
+	'P',	'Q',	'R',	'S',	'T',	'U',	'V',	'W',	
+	'X',	'Y',	'Z',	'{',	DOSILG,	'}',	'~',	DOSILG,	/*7x*/
+};
+
+/* [FIXME]
+	configure script need to check whether char-type is signed or unsigned !
+*/
+#if 0
+#define CONV_DOS_FILE_CHAR(c)	(((c)<128) ? char_check_table[(c)] : 1)
+#else
+#define CONV_DOS_FILE_CHAR(c)	(((c)>=0) ? char_check_table[(c)] : 1)
+#endif
+
 /** **************************************************************************
 ************************************************************************** **/
 int
@@ -186,27 +240,39 @@ TFatfs_NormalizeName(TFatDirEnt* ep, const char* name)
 	int i;
 	const char* p = name;
 	char c;
+	uint8 oc;
 
 	memset(ep->name, ' ', 8);
 	memset(ep->ext, ' ', 3);
 
 	for (i = 0 ; i < 8 ; i++) {
 		c = *p++;
-		if (c == 0) {
+		oc = CONV_DOS_FILE_CHAR(c);
+		if (oc == DOSTRM) {
 			return 1;
-		} else if (c == '.') {
+		} else if (oc == DOSILG) {
+			return 0;
+		} else if (oc == '.') {
+			--p;
 			break;
 		}
-		ep->name[i] = c;
+		ep->name[i] = oc;
 	}
-	for (i = 0 ; i < 8 ; i++) {
+	if (*p == '.') {
+		p++;
+	}
+	for (i = 0 ; i < 3 ; i++) {
 		c = *p++;
-		if (c == 0) {
+		oc = CONV_DOS_FILE_CHAR(c);
+		if (oc == DOSTRM) {
 			return 1;
-		} else if (c == '.') {
+		} else if (oc == DOSILG) {
+			return 0;
+		} else if (oc == '.') {
+			--p;
 			break;
 		}
-		ep->ext[i] = c;
+		ep->ext[i] = oc;
 	}
 	return (*p == 0) ? 1 : 0;
 }
@@ -837,7 +903,9 @@ void showhelp(void)
 	/* mkimage.fatfs */
 	fprintf(stderr, "Usage: %s [options]\n"
 	/* --------1---------2---------3---------4---------5---------6---------7---------8 */
-	"mkimgfatfs Version " VERSION "\n"
+	"mkimgfatfs " VERSION " (c) 2002-2005 N.Masuichi <nor at users.sourceforge.jp>\n"
+	"  derived from: genext2fs (C) 2000 Xavier Bestel <xavier.bestel at free.fr>\n"
+	"\n"
 	"Base image:\n"
 	"  -s image	Use this image as a starting point\n"
 	"               (default: Create NEW filesystem image.)\n"
