@@ -8,6 +8,18 @@
 	modify it under the terms of the GNU General Public License
 	as published by the Free Software Foundation; either version
 	2 of the License, or (at your option) any later version.
+
+	This code is derived from:
+
+	genext2fs.c
+
+	ext2 filesystem generator for embedded systems
+	Copyright (C) 2000 Xavier Bestel <xavier.bestel@free.fr>
+
+	This program is free software; you can redistribute it and/or
+	modify it under the terms of the GNU General Public License
+	as published by the Free Software Foundation; version
+	2 of the License.
 **/
 
 #ifdef HAVE_CONFIG_H
@@ -41,7 +53,7 @@ typedef struct {
 	int nbinodes;
 	int nbresrvd;
 	int nbnamelen;
-} TExt2fsParam;
+} TMinixfsParam;
 
 TVfs* TMinixfs_LoadFromFile(TVfsOps*, TVfsParam*, FILE * fh);
 TVfs* TMinixfs_CreateFs(TVfsOps*, TVfsParam*);
@@ -733,7 +745,7 @@ TMinixfs_GetRootInodeNo(TVfs* fs)
 TVfs*
 TMinixfs_CreateFs(TVfsOps* vfsops, TVfsParam* param)
 {
-	TExt2fsParam* p = (TExt2fsParam*)param;
+	TMinixfsParam* p = (TMinixfsParam*)param;
 	int i;
 	TMinixfs *fs;
 	directory *d;
@@ -1158,8 +1170,8 @@ TMinixfs_FillUnallocatedBlock(TVfs* vfs, char c)
 
 /** **************************************************************************
 ************************************************************************** **/
-TVfsOps st_ext2fsops = {
-	.mFilesystemName = "ext2fs",
+TVfsOps st_minixfsops = {
+	.mFilesystemName = "minixfs",
 	.mfLoadFromFile = TMinixfs_LoadFromFile,
 	.mfCreateFs = TMinixfs_CreateFs,
 	.mfGetRootInodeNo = TMinixfs_GetRootInodeNo,
@@ -1180,7 +1192,9 @@ void showhelp(void)
 	/* mkimage.ext2fs */
 	fprintf(stderr, "Usage: %s [options]\n"
 	/* --------1---------2---------3---------4---------5---------6---------7---------8 */
-	"mkimgminixfs Version " VERSION "\n"
+	"mkimgminixfs " VERSION " (c) 2002-2005 N.Masuichi <nor at users.sourceforge.jp>\n"
+	"  derived from: genext2fs (C) 2000 Xavier Bestel <xavier.bestel at free.fr>\n"
+	"\n"
 	"Base image:\n"
 	"  -s image	Use this image as a starting point\n"
 	"               (default: Create NEW filesystem image.)\n"
@@ -1217,7 +1231,7 @@ void showhelp(void)
 int
 main(int argc, char **argv)
 {
-	TExt2fsParam param = {
+	TMinixfsParam param = {
 		.mCommon = {
 			.fsin = NULL,
 			.fsspec = NULL,
@@ -1291,7 +1305,7 @@ main(int argc, char **argv)
 		errexit("too many arguments");
 	}
 
-	return TVfs_MakeImage(&st_ext2fsops, (TVfsParam*)&param);
+	return TVfs_MakeImage(&st_minixfsops, (TVfsParam*)&param);
 }
 
 /* END-OF-FILE */
